-- ----------------------------------------------------------------
-- SASAPP Schema definition script: Job execution 
-- 
-- Supported DBMS: MSSQL
-- ----------------------------------------------------------------

/* ----------------------------------------------------------------------- 
 * SAS_JES_JOBS
 * ----------------------------------------------------------------------- */

create table SAS_JES_JOBS
(
    JOB_ID char(36) not null,
    JOB_NM varchar(60) not null,
    JOB_DESC varchar(200),
    JOB_PRIORITY_CD varchar(6) not null,
    CLIENT_IDENTITY_TXT varchar(60) not null,
    CLIENT_PRINCIPAL_TXT varchar(128) not null,
    CLIENT_DOMAIN_TXT varchar(60) not null,
    EXECUTION_TYPE_CD varchar(10) not null,
    EXECUTION_STATE_CD varchar(10) not null,
    REUSING_CONNECTIONS_FLG tinyint default 1 not null,
    MAX_QUEUED_TIME_NO bigint,
    MAX_QUEUED_TIME_FOR_TASKS_NO bigint,
    MAX_EXEC_TIME_NO bigint,
    MAX_EXEC_TIME_FOR_TASKS_NO bigint,
    SUBMITTED_TIME_DTTM datetime not null,
    QUEUED_TIME_DTTM datetime,
    STARTED_TIME_DTTM datetime,
    COMPLETED_TIME_DTTM datetime,
    COMPLETED_EXECUTIONS_NO int,
    primary key (JOB_ID)
);


/* ----------------------------------------------------------------------- 
 * SAS_JES_TASKS
 * ----------------------------------------------------------------------- */

create table SAS_JES_TASKS
(
    JOB_ID char(36) not null,
    TASK_ID char(36) not null,
    TASK_NM varchar(60) not null,
    TASK_DESC varchar(200),
    TASK_TYPE_CD varchar(14) not null,
    STP_PATH_TXT text,
    EXECUTION_STATE_CD varchar(10) not null,
    COMPLETION_TYPE_CD varchar(12) not null,
    EXCEPTION_MSG_TXT text,
    SERVER_CONTEXT_NM varchar(60),
    MAX_QUEUED_TIME_NO bigint,
    MAX_EXEC_TIME_NO bigint,
    SUBMITTED_TIME_DTTM datetime not null,
    QUEUED_TIME_DTTM datetime,
    STARTED_TIME_DTTM datetime,
    COMPLETED_TIME_DTTM datetime,
    COMPLETED_EXECUTIONS_NO int,
    RUNAS_CLIENTIDENTITY_FLG tinyint default 0 not null,
    PERSISTING_RESULTPACKAGE_FLG tinyint default 0 not null,
    PROMPT_VALUES_TXT text,
    primary key (TASK_ID)
);


/* ----------------------------------------------------------------------- 
 * SAS_JES_TASK_SASCODE
 * ----------------------------------------------------------------------- */

create table SAS_JES_TASK_SASCODE
(
    TASK_ID char(36) not null,
    SASCODE_TXT text not null
);


/* ----------------------------------------------------------------------- 
 * SAS_JES_TASK_INPUT_NAMES
 * ----------------------------------------------------------------------- */

create table SAS_JES_TASK_INPUT_NAMES
(
    TASK_ID char(36) not null,
    INPUT_NM varchar(32) not null
);


/* ----------------------------------------------------------------------- 
 * SAS_JES_TASK_INPUT_VALUES
 * ----------------------------------------------------------------------- */

create table SAS_JES_TASK_INPUT_VALUES
(
    TASK_ID char(36) not null,
    INPUT_NM varchar(32) not null,
    INPUT_VALUE_TXT text
);


/* ----------------------------------------------------------------------- 
 * SAS_JES_TASK_OUTPUT_NAMES
 * ----------------------------------------------------------------------- */

create table SAS_JES_TASK_OUTPUT_NAMES
(
    TASK_ID char(36) not null,
    OUTPUT_NM varchar(32) not null
);


/* ----------------------------------------------------------------------- 
 * SAS_JES_TASK_RESOURCES
 * ----------------------------------------------------------------------- */

create table SAS_JES_TASK_RESOURCES
(
    TASK_ID char(36) not null,
    RESOURCE_NM varchar(32) not null
);


/* ----------------------------------------------------------------------- 
 * SAS_JES_TASK_RESULTS
 * ----------------------------------------------------------------------- */

create table SAS_JES_TASK_RESULTS
(
    TASK_ID char(36) not null,
    OUTPUT_NM varchar(32) not null,
    OUTPUT_VALUE_TXT text
);

/* ----------------------------------------------------------------------- 
 * SAS_JES_TASK_LOGS
 * ----------------------------------------------------------------------- */

create table SAS_JES_TASK_LOGS
(
    TASK_ID char(36) not null,
    LINE_NO int,
    LINE_TYPE_CD varchar(11) not null,
    CC_TYPE_CD varchar(12) not null,
    MSG_TYPE_CD varchar(10) not null,
    LINE_TXT text not null,
    APP_NM varchar(32)
);


/* ----------------------------------------------------------------------- 
 * SAS_JES_TASK_LISTS
 * ----------------------------------------------------------------------- */

create table SAS_JES_TASK_LISTS
(
    TASK_ID char(36) not null,
    LINE_NO int,
    LINE_TYPE_CD varchar(11) not null,
    CC_TYPE_CD varchar(12) not null,
    LINE_TXT text not null
    
);

alter table SAS_JES_TASKS
    add constraint SAS_JES_TASKS_FK01 foreign key (JOB_ID) references SAS_JES_JOBS (JOB_ID)
    on delete cascade on update cascade;
    
alter table SAS_JES_TASK_SASCODE
    add constraint SAS_JES_TASK_SASCODE_FK01 foreign key (TASK_ID) references SAS_JES_TASKS (TASK_ID)
    on delete cascade on update cascade;
 
alter table SAS_JES_TASK_INPUT_NAMES
    add constraint SAS_JES_TASK_INPUT_NAMES_FK01 foreign key (TASK_ID) references SAS_JES_TASKS (TASK_ID)
    on delete cascade on update cascade;

alter table SAS_JES_TASK_INPUT_VALUES
    add constraint SAS_JES_TASK_INPUT_VALUES_FK01 foreign key (TASK_ID) references SAS_JES_TASKS (TASK_ID)
    on delete cascade on update cascade;

alter table SAS_JES_TASK_OUTPUT_NAMES
    add constraint SAS_JES_TASK_OUTPUT_NAMES_FK01 foreign key (TASK_ID) references SAS_JES_TASKS (TASK_ID)
    on delete cascade on update cascade;

alter table SAS_JES_TASK_RESOURCES
    add constraint SAS_JES_TASK_RESOURCES_FK01 foreign key (TASK_ID) references SAS_JES_TASKS (TASK_ID)
    on delete cascade on update cascade;

alter table SAS_JES_TASK_RESULTS
    add constraint SAS_JES_TASK_RESULTS_FK01 foreign key (TASK_ID) references SAS_JES_TASKS (TASK_ID)
    on delete cascade on update cascade;
