-- ----------------------------------------------------------------
-- SASAPP Schema definition script: Job execution
-- 
-- Supported DBMS: MYSQL
-- ----------------------------------------------------------------

-- ----------------------------------------------------------------------- 
-- SAS_JES_JOBS
-- ----------------------------------------------------------------------- 

CREATE TABLE SAS_JES_JOBS
(
    JOB_ID CHAR(36) NOT NULL,
    JOB_NM VARCHAR(60) NOT NULL,
    JOB_DESC VARCHAR(200),
    JOB_PRIORITY_CD ENUM('low', 'normal', 'high') NOT NULL,
    CLIENT_IDENTITY_TXT VARCHAR(60) NOT NULL,
    CLIENT_PRINCIPAL_TXT VARCHAR(128) NOT NULL,
    CLIENT_DOMAIN_TXT VARCHAR(60) NOT NULL,
    EXECUTION_TYPE_CD ENUM('immediate', 'batch', 'scheduled') NOT NULL,
    EXECUTION_STATE_CD ENUM('submitted', 'queued', 'running', 'completed') NOT NULL,
    REUSING_CONNECTIONS_FLG TINYINT DEFAULT 1 NOT NULL,
    MAX_QUEUED_TIME_NO BIGINT,
    MAX_QUEUED_TIME_FOR_TASKS_NO BIGINT,
    MAX_EXEC_TIME_NO BIGINT,
    MAX_EXEC_TIME_FOR_TASKS_NO BIGINT,
    SUBMITTED_TIME_DTTM DATETIME NOT NULL,
    QUEUED_TIME_DTTM DATETIME,
    STARTED_TIME_DTTM DATETIME,
    COMPLETED_TIME_DTTM DATETIME,
    COMPLETED_EXECUTIONS_NO int,
    PRIMARY KEY (JOB_ID)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COLLATE=utf8_bin;


-- ----------------------------------------------------------------------- 
-- SAS_JES_TASKS
-- ----------------------------------------------------------------------- 

CREATE TABLE SAS_JES_TASKS
(
    JOB_ID CHAR(36) NOT NULL,
    TASK_ID CHAR(36) NOT NULL,
    TASK_NM VARCHAR(60) NOT NULL,
    TASK_DESC VARCHAR(200),
    TASK_TYPE_CD ENUM('sasCode', 'storedProcess') NOT NULL,
    STP_PATH_TXT TEXT,
    EXECUTION_STATE_CD ENUM('submitted', 'queued', 'running', 'completed') NOT NULL,
    COMPLETION_TYPE_CD ENUM('unavailable', 'normal', 'canceled', 'sigabort', 'timeout', 'exception') NOT NULL,
    EXCEPTION_MSG_TXT TEXT,
    SERVER_CONTEXT_NM VARCHAR(60),
    MAX_QUEUED_TIME_NO BIGINT,
    MAX_EXEC_TIME_NO BIGINT,
    SUBMITTED_TIME_DTTM DATETIME NOT NULL,
    QUEUED_TIME_DTTM DATETIME,
    STARTED_TIME_DTTM DATETIME,
    COMPLETED_TIME_DTTM DATETIME,
    COMPLETED_EXECUTIONS_NO int,
    RUNAS_CLIENTIDENTITY_FLG TINYINT DEFAULT 0 NOT NULL,
    PERSISTING_RESULTPACKAGE_FLG TINYINT DEFAULT 0 NOT NULL,
    PROMPT_VALUES_TXT TEXT,
    PRIMARY KEY (TASK_ID)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COLLATE=utf8_bin;

-- ----------------------------------------------------------------------- 
-- SAS_JES_TASK_SASCODE
-- ----------------------------------------------------------------------- 

CREATE TABLE SAS_JES_TASK_SASCODE
(
    TASK_ID CHAR(36) NOT NULL,
    SASCODE_TXT TEXT NOT NULL
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COLLATE=utf8_bin;


-- ----------------------------------------------------------------------- 
-- SAS_JES_TASK_INPUT_NAMES
-- ----------------------------------------------------------------------- 

CREATE TABLE SAS_JES_TASK_INPUT_NAMES
(
    TASK_ID CHAR(36) NOT NULL,
    INPUT_NM VARCHAR(32) NOT NULL
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COLLATE=utf8_bin;


-- ----------------------------------------------------------------------- 
-- SAS_JES_TASK_INPUT_VALUES
-- ----------------------------------------------------------------------- 

CREATE TABLE SAS_JES_TASK_INPUT_VALUES
(
    TASK_ID CHAR(36) NOT NULL,
    INPUT_NM VARCHAR(32) NOT NULL,
    INPUT_VALUE_TXT TEXT
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COLLATE=utf8_bin;


-- ----------------------------------------------------------------------- 
-- SAS_JES_TASK_OUTPUT_NAMES
-- ----------------------------------------------------------------------- 

CREATE TABLE SAS_JES_TASK_OUTPUT_NAMES
(
    TASK_ID CHAR(36) NOT NULL,
    OUTPUT_NM VARCHAR(32) NOT NULL
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COLLATE=utf8_bin;


-- ----------------------------------------------------------------------- 
-- SAS_JES_TASK_RESOURCES
-- ----------------------------------------------------------------------- 

CREATE TABLE SAS_JES_TASK_RESOURCES
(
    TASK_ID CHAR(36) NOT NULL,
    RESOURCE_NM VARCHAR(32) NOT NULL
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COLLATE=utf8_bin;


-- ----------------------------------------------------------------------- 
-- SAS_JES_TASK_RESULTS
-- ----------------------------------------------------------------------- 

CREATE TABLE SAS_JES_TASK_RESULTS
(
    TASK_ID CHAR(36) NOT NULL,
    OUTPUT_NM VARCHAR(32) NOT NULL,
    OUTPUT_VALUE_TXT TEXT
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COLLATE=utf8_bin;

-- ----------------------------------------------------------------------- 
-- SAS_JES_TASK_LOGS
-- ----------------------------------------------------------------------- 

CREATE TABLE SAS_JES_TASK_LOGS
(
    TASK_ID CHAR(36) NOT NULL,
    LINE_NO INT,
    LINE_TYPE_CD VARCHAR(11) NOT NULL,
    CC_TYPE_CD VARCHAR(12) NOT NULL,
    MSG_TYPE_CD VARCHAR(10) NOT NULL,
    LINE_TXT TEXT NOT NULL,
    APP_NM VARCHAR(32)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COLLATE=utf8_bin;


-- ----------------------------------------------------------------------- 
-- SAS_JES_TASK_LISTS
-- ----------------------------------------------------------------------- 

CREATE TABLE SAS_JES_TASK_LISTS
(
    TASK_ID CHAR(36) NOT NULL,
    LINE_NO INT,
    LINE_TYPE_CD VARCHAR(11) NOT NULL,
    CC_TYPE_CD VARCHAR(12) NOT NULL,
    LINE_TXT TEXT NOT NULL
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COLLATE=utf8_bin;

ALTER TABLE SAS_JES_TASKS
    ADD CONSTRAINT SAS_JES_TASKS_FK01 FOREIGN KEY (JOB_ID) REFERENCES SAS_JES_JOBS (JOB_ID) ON DELETE CASCADE ON UPDATE CASCADE;

ALTER TABLE SAS_JES_TASK_SASCODE
    ADD CONSTRAINT SAS_JES_TASK_SASCODE_FK01 FOREIGN KEY (TASK_ID) REFERENCES SAS_JES_TASKS (TASK_ID) ON DELETE CASCADE ON UPDATE CASCADE;

ALTER TABLE SAS_JES_TASK_INPUT_NAMES
    ADD CONSTRAINT SAS_JES_TASK_INPUT_NAMES_FK01 FOREIGN KEY (TASK_ID) REFERENCES SAS_JES_TASKS (TASK_ID) ON DELETE CASCADE ON UPDATE CASCADE;

ALTER TABLE SAS_JES_TASK_INPUT_VALUES
    ADD CONSTRAINT SAS_JES_TASK_INPUT_VALUES_FK01 FOREIGN KEY (TASK_ID) REFERENCES SAS_JES_TASKS (TASK_ID) ON DELETE CASCADE ON UPDATE CASCADE;

ALTER TABLE SAS_JES_TASK_OUTPUT_NAMES
    ADD CONSTRAINT SAS_JES_TASK_OUTPUT_NAMES_FK01 FOREIGN KEY (TASK_ID) REFERENCES SAS_JES_TASKS (TASK_ID) ON DELETE CASCADE ON UPDATE CASCADE;

ALTER TABLE SAS_JES_TASK_RESOURCES
    ADD CONSTRAINT SAS_JES_TASK_RESOURCES_FK01 FOREIGN KEY (TASK_ID) REFERENCES SAS_JES_TASKS (TASK_ID) ON DELETE CASCADE ON UPDATE CASCADE;

ALTER TABLE SAS_JES_TASK_RESULTS
    ADD CONSTRAINT SAS_JES_TASK_RESULTS_FK01 FOREIGN KEY (TASK_ID) REFERENCES SAS_JES_TASKS (TASK_ID) ON DELETE CASCADE ON UPDATE CASCADE;

-- do not create foreign key since logs can exist even when the task is not persisted
-- ALTER TABLE SAS_JES_TASK_LOGS
--     ADD CONSTRAINT SAS_JES_TASK_LOGS_FK01 FOREIGN KEY (TASK_ID) REFERENCES SAS_JES_TASKS (TASK_ID) ON DELETE CASCADE ON UPDATE CASCADE;

-- do not create foreign key since listings can exist even when the task is not persisted
-- ALTER TABLE SAS_JES_TASK_LISTS
--     ADD CONSTRAINT SAS_JES_TASK_LISTS_FK01 FOREIGN KEY (TASK_ID) REFERENCES SAS_JES_TASKS (TASK_ID) ON DELETE CASCADE ON UPDATE CASCADE;
