-- ----------------------------------------------------------------
-- SASAPP Schema definition script: Job execution
-- 
-- Supported DBMS: ORACLE
-- ----------------------------------------------------------------

-- -------------------------------------------------------------------------
-- SAS_JES_JOBS
-- -------------------------------------------------------------------------

create table SAS_JES_JOBS
(
    JOB_ID char(36) not null enable,
    JOB_NM varchar2(60 char) not null enable,
    JOB_DESC varchar2(200 char),
    JOB_PRIORITY_CD varchar2(6 char) not null enable,
    CLIENT_IDENTITY_TXT varchar2(60 char) not null enable,
    CLIENT_PRINCIPAL_TXT varchar2(128 char) not null enable,
    CLIENT_DOMAIN_TXT varchar2(60 char) not null enable,
    EXECUTION_TYPE_CD varchar2(10 char) not null enable,
    EXECUTION_STATE_CD varchar2(10 char) not null enable,
    REUSING_CONNECTIONS_FLG number(1,0) default 1 not null enable,
    MAX_QUEUED_TIME_NO number(*,0),
    MAX_QUEUED_TIME_FOR_TASKS_NO number(*,0),
    MAX_EXEC_TIME_NO number(*,0),
    MAX_EXEC_TIME_FOR_TASKS_NO number(*,0),
    SUBMITTED_TIME_DTTM date not null enable,
    QUEUED_TIME_DTTM date,
    STARTED_TIME_DTTM date,
    COMPLETED_TIME_DTTM date,
    COMPLETED_EXECUTIONS_NO number(*,0),
    constraint SAS_JES_JOBS_PK primary key (JOB_ID) enable
);

-- -------------------------------------------------------------------------
-- SAS_JES_TASKS
-- -------------------------------------------------------------------------

create table SAS_JES_TASKS
(
    JOB_ID char(36) not null enable,
    TASK_ID char(36) not null enable,
    TASK_NM varchar2(60 char) not null enable,
    TASK_DESC varchar2(200 char),
    TASK_TYPE_CD varchar2(14 char) not null enable,
    STP_PATH_TXT varchar2(4000 char),
    EXECUTION_STATE_CD varchar2(10 char) not null enable,
    COMPLETION_TYPE_CD varchar2(12 char) not null enable,
    EXCEPTION_MSG_TXT varchar2(4000 char),
    SERVER_CONTEXT_NM varchar2(60 char),
    MAX_QUEUED_TIME_NO number(*,0),
    MAX_EXEC_TIME_NO number(*,0),
    SUBMITTED_TIME_DTTM date not null enable,
    QUEUED_TIME_DTTM date,
    STARTED_TIME_DTTM date,
    COMPLETED_TIME_DTTM date,
    COMPLETED_EXECUTIONS_NO number(*,0),
    RUNAS_CLIENTIDENTITY_FLG number(1,0) default 0 not null enable,
    PERSISTING_RESULTPACKAGE_FLG number(1,0) default 0 not null enable,
    PROMPT_VALUES_TX clob,
    constraint SAS_JES_TASKS primary key (TASK_ID) enable
);

-- -------------------------------------------------------------------------
-- SAS_JES_TASK_SASCODE
-- -------------------------------------------------------------------------

create table SAS_JES_TASK_SASCODE
(
    TASK_ID char(36) not null enable,
    SASCODE_TXT varchar2(4000 char) not null enable
);

-- -------------------------------------------------------------------------
-- SAS_JES_TASK_INPUT_NAMES
-- -------------------------------------------------------------------------

create table SAS_JES_TASK_INPUT_NAMES
(
    TASK_ID char(36) not null enable,
    INPUT_NM varchar2(32 char) not null enable
);

-- -------------------------------------------------------------------------
-- SAS_JES_TASK_INPUT_VALUES
-- -------------------------------------------------------------------------

create table SAS_JES_TASK_INPUT_VALUES
(
    TASK_ID char(36) not null enable,
    INPUT_NM varchar2(32 char) not null enable,
    INPUT_VALUE_TXT clob
);

-- -------------------------------------------------------------------------
-- SAS_JES_TASK_OUTPUT_NAMES
-- -------------------------------------------------------------------------

create table SAS_JES_TASK_OUTPUT_NAMES
(
    TASK_ID char(36) not null enable,
    OUTPUT_NM varchar2(32 char) not null enable
);

-- -------------------------------------------------------------------------
-- SAS_JES_TASK_RESOURCES
-- -------------------------------------------------------------------------

create table SAS_JES_TASK_RESOURCES
(
    TASK_ID char(36) not null enable,
    RESOURCE_NM varchar2(32 char) not null enable
);

-- -------------------------------------------------------------------------
-- SAS_JES_TASK_RESULTS
-- -------------------------------------------------------------------------

create table SAS_JES_TASK_RESULTS
(
    TASK_ID char(36) not null enable,
    OUTPUT_NM varchar2(32 char) not null enable,
    OUTPUT_VALUE_TXT clob
);

-- -------------------------------------------------------------------------
-- SAS_JES_TASK_LOGS
-- -------------------------------------------------------------------------

create table SAS_JES_TASK_LOGS
(
    TASK_ID char(36) not null enable,
    LINE_NO number(*,0),
    LINE_TYPE_CD varchar2(11 char) not null enable,
    CC_TYPE_CD varchar2(12 char) not null enable,
    MSG_TYPE_CD varchar2(10 char) not null enable,
    LINE_TXT varchar2(4000 char),
    APP_NM varchar2(32)
);

-- -------------------------------------------------------------------------
-- SAS_JES_TASK_LISTS
-- -------------------------------------------------------------------------

create table SAS_JES_TASK_LISTS
(
    TASK_ID char(36) not null enable,
    LINE_NO number(*,0),
    LINE_TYPE_CD varchar2(11 char) not null enable,
    CC_TYPE_CD varchar2(12 char) not null enable,
    LINE_TXT varchar2(4000 char)
);

alter table SAS_JES_TASKS
    add constraint SAS_JES_TASKS_FK01 foreign key (JOB_ID) references SAS_JES_JOBS (JOB_ID)
    on delete cascade;

alter table SAS_JES_TASK_SASCODE
    add constraint SAS_JES_TASK_SASCODE_FK01 foreign key (TASK_ID) references SAS_JES_TASKS (TASK_ID)
    on delete cascade;

alter table SAS_JES_TASK_INPUT_NAMES
    add constraint SAS_JES_TASK_INPUT_NAMES_FK01 foreign key (TASK_ID) references SAS_JES_TASKS (TASK_ID)
    on delete cascade;

alter table SAS_JES_TASK_INPUT_VALUES
    add constraint SAS_JES_TASK_INPUT_VALUES_FK01 foreign key (TASK_ID) references SAS_JES_TASKS (TASK_ID)
    on delete cascade;

alter table SAS_JES_TASK_OUTPUT_NAMES
    add constraint SAS_JES_TASK_OUTPUT_NAMES_FK01 foreign key (TASK_ID) references SAS_JES_TASKS (TASK_ID)
    on delete cascade;

alter table SAS_JES_TASK_RESOURCES
    add constraint SAS_JES_TASK_RESOURCES_FK01 foreign key (TASK_ID) references SAS_JES_TASKS (TASK_ID)
    on delete cascade;

alter table SAS_JES_TASK_RESULTS
    add constraint SAS_JES_TASK_RESULTS_FK01 foreign key (TASK_ID) references SAS_JES_TASKS (TASK_ID)
    on delete cascade;

-- do not create foreign keys for logs or listings since they can exist even when the task is not persisted --
