-- ----------------------------------------------------------------
-- SASAPP Schema definition script: Job execution
-- 
-- Supported DBMS: POSTGRES
-- ----------------------------------------------------------------

-- ------------------------------------------------------------------------
-- SAS_JES_JOBS
-- ------------------------------------------------------------------------

create table SAS_JES_JOBS
(
    JOB_ID character(36) not null,
    JOB_NM character varying(60) not null,
    JOB_DESC character varying(200),
    JOB_PRIORITY_CD character varying(6) not null,
    CLIENT_IDENTITY_TXT character varying(60) not null,
    CLIENT_PRINCIPAL_TXT character varying(128) not null,
    CLIENT_DOMAIN_TXT character varying(60) not null,
    EXECUTION_TYPE_CD character varying(10) not null,
    EXECUTION_STATE_CD character varying(10) not null,
    REUSING_CONNECTIONS_FLG boolean default true not null,
    MAX_QUEUED_TIME_NO bigint,
    MAX_QUEUED_TIME_FOR_TASKS_NO bigint,
    MAX_EXEC_TIME_NO bigint,
    MAX_EXEC_TIME_FOR_TASKS_NO bigint,
    SUBMITTED_TIME_DTTM timestamp without time zone not null,
    QUEUED_TIME_DTTM timestamp without time zone,
    STARTED_TIME_DTTM timestamp without time zone,
    COMPLETED_TIME_DTTM timestamp without time zone,
    COMPLETED_EXECUTIONS_NO integer,
    constraint SAS_JES_JOBS_PK primary key (JOB_ID)
)
with (oids=false);

-- -------------------------------------------------------------------------
-- SAS_JES_TASKS
-- -------------------------------------------------------------------------

create table SAS_JES_TASKS
(
    JOB_ID character(36) not null,
    TASK_ID character(36) not null,
    TASK_NM character varying(60) not null,
    TASK_DESC character varying(200),
    TASK_TYPE_CD character varying(14) not null,
    STP_PATH_TXT text,
    EXECUTION_STATE_CD character varying(10) not null,
    COMPLETION_TYPE_CD character varying(12) not null,
    EXCEPTION_MSG_TXT text,
    SERVER_CONTEXT_NM character varying(60),
    MAX_QUEUED_TIME_NO bigint,
    MAX_EXEC_TIME_NO bigint,
    SUBMITTED_TIME_DTTM timestamp without time zone not null,
    QUEUED_TIME_DTTM timestamp without time zone,
    STARTED_TIME_DTTM timestamp without time zone,
    COMPLETED_TIME_DTTM timestamp without time zone,
    COMPLETED_EXECUTIONS_NO integer,
    RUNAS_CLIENTIDENTITY_FLG boolean default false not null,
    PERSISTING_RESULTPACKAGE_FLG boolean default false not null,
    PROMPT_VALUES_TXT text,
    constraint SAS_JES_TASKS_FK01 foreign key (JOB_ID)
        references SAS_JES_JOBS (JOB_ID) match full
        on update cascade on delete cascade,
    constraint SAS_JES_TASKS_PK primary key (TASK_ID)
)
with (oids=false);

-- -------------------------------------------------------------------------
-- SAS_JES_TASK_SASCODE
-- -------------------------------------------------------------------------

create table SAS_JES_TASK_SASCODE
(
    TASK_ID character(36) not null,
    SASCODE_TXT text not null,
    constraint SAS_JES_TASK_SASCODE_FK01 foreign key (TASK_ID)
        references SAS_JES_TASKS (TASK_ID) match full
        on update cascade on delete cascade
)
with (oids=false);

-- -------------------------------------------------------------------------
-- SAS_JES_TASK_INPUT_NAMES
-- -------------------------------------------------------------------------

create table SAS_JES_TASK_INPUT_NAMES
(
    TASK_ID character(36) not null,
    INPUT_NM character varying(32) not null,
    constraint SAS_JES_TASK_INPUT_NAMES_FK01 foreign key (TASK_ID)
        references SAS_JES_TASKS (TASK_ID) match full
        on update cascade on delete cascade
)
with (oids=false);

-- -------------------------------------------------------------------------
-- SAS_JES_TASK_INPUT_VALUES
-- -------------------------------------------------------------------------

create table SAS_JES_TASK_INPUT_VALUES
(
    TASK_ID character(36) not null,
    INPUT_NM character varying(32) not null,
    INPUT_VALUE_TXT text,
    constraint SAS_JES_TASK_INPUT_VALUES_FK01 foreign key (TASK_ID)
        references SAS_JES_TASKS (TASK_ID) match full
        on update cascade on delete cascade
)
with (oids=false);

-- -------------------------------------------------------------------------
-- SAS_JES_TASK_OUTPUT_NAMES
-- -------------------------------------------------------------------------

create table SAS_JES_TASK_OUTPUT_NAMES
(
    TASK_ID character(36) not null,
    OUTPUT_NM character varying(32) not null,
    constraint SAS_JES_TASK_OUTPUT_NAMES_FK01 foreign key (TASK_ID)
        references SAS_JES_TASKS (TASK_ID) match full
        on update cascade on delete cascade
)
with (oids=false);

-- -------------------------------------------------------------------------
-- SAS_JES_TASK_RESOURCES
-- -------------------------------------------------------------------------

create table SAS_JES_TASK_RESOURCES
(
    TASK_ID character(36) not null,
    RESOURCE_NM character varying(32) not null,
    constraint SAS_JES_TASK_RESOURCES_FK01 foreign key (TASK_ID)
        references SAS_JES_TASKS (TASK_ID) match full
        on update cascade on delete cascade
)
with (oids=false);
      
-- -------------------------------------------------------------------------
-- SAS_JES_TASK_RESULTS
-- -------------------------------------------------------------------------

create table SAS_JES_TASK_RESULTS
(
    TASK_ID character(36) not null,
    OUTPUT_NM character varying(32) not null,
    OUTPUT_VALUE_TXT text,
    constraint SAS_JES_TASK_RESULTS_FK01 foreign key (TASK_ID)
        references SAS_JES_TASKS (TASK_ID) match full
        on update cascade on delete cascade
)
with (oids=false);

-- -------------------------------------------------------------------------
-- SAS_JES_TASK_LOGS
-- -------------------------------------------------------------------------

create table SAS_JES_TASK_LOGS
(
    TASK_ID character(36) not null,
    LINE_NO integer,
    LINE_TYPE_CD character varying(11) not null,
    CC_TYPE_CD character varying(12) not null,
    MSG_TYPE_CD character varying(10) not null,
    LINE_TXT text not null,
    APP_NM character varying(32)
)
with (oids=false);

-- -------------------------------------------------------------------------
-- SAS_JES_TASK_LISTS
-- -------------------------------------------------------------------------

create table SAS_JES_TASK_LISTS
(
    TASK_ID character(36) not null,
    LINE_NO integer,
    LINE_TYPE_CD character varying(11) not null,
    CC_TYPE_CD character varying(12) not null,
    LINE_TXT text not null
)
with (oids=false);

create index SAS_JES_TASKS_FK011
  on SAS_JES_TASKS
  using btree (JOB_ID);

create index SAS_JES_TASK_SASCODE_FK011
  on SAS_JES_TASK_SASCODE
  using btree (TASK_ID);

create index SAS_JES_TASK_INPUT_NAMES_FK011
  on SAS_JES_TASK_INPUT_NAMES
  using btree (TASK_ID);

create index SAS_JES_TASK_INPUT_VALUES_FK011
  on SAS_JES_TASK_INPUT_VALUES
  using btree (TASK_ID);

create index SAS_JES_TASK_OUTPUT_NAMES_FK011
  on SAS_JES_TASK_OUTPUT_NAMES
  using btree (TASK_ID);

create index SAS_JES_TASK_RESOURCES_FK011
  on SAS_JES_TASK_RESOURCES
  using btree (TASK_ID);

create index SAS_JES_TASK_RESULTS_FK011
  on SAS_JES_TASK_RESULTS
  using btree (TASK_ID);


-- do not create foreign keys for logs or listings since they can exist even when the task is not persisted --
